OC.L10N.register(
    "core",
    {
    "Please select a file." : "لطفا فایل مورد نظر را انتخاب کنید ",
    "File is too big" : "فایل خیلی بزرگ است",
    "The selected file is not an image." : "فایل انتخاب شده عکس نمی باشد.",
    "The selected file cannot be read." : "فایل انتخاب شده خوانده نمی شود.",
    "The file was uploaded" : "پرونده، بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پرونده بازگذاری شده بیشتر از تنظیمات MAX_FILE_SIZE مشخص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شد",
    "No file was uploaded" : "پرونده‌ای بارگذاری نشد",
    "Missing a temporary folder" : "پوشه موقت موجود نیست",
    "Could not write file to disk" : "ناتوانی در نوشتن پرونده روی حافظه",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "Invalid image" : "عکس نامعتبر",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
    "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "State token does not match" : "State token مطابقت ندارد",
    "Invalid app password" : "کلمه عبور اپلیکیشن اشتباه است",
    "Could not complete login" : "فرایند ورود شما به سیستم کامل نشد",
    "State token missing" : "State token missing",
    "Your login token is invalid or has expired" : "اطلاعات توکن ورود شما اشتباه یا منقضی است",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
    "Login" : "ورود",
    "Password reset is disabled" : "تنظیم مجدد رمز عبور فعال نیست",
    "Could not reset password because the token is expired" : "رمز عبور بازنشانی نشد زیرا رمز منقضی شده است",
    "Could not reset password because the token is invalid" : "رمز عبور بازنشانی نشد زیرا رمز نامعتبر است",
    "Password is too long. Maximum allowed length is 469 characters." : "رمز عبور خیلی طولانی است. حداکثر طول مجاز 469 کاراکتر است.",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Password reset" : "تنظیم مجدد رمز عبور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی دکمه زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی لینک زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
    "Reset your password" : "تنظیم مجدد رمز عبور",
    "Task not found" : "Task not found",
    "Internal error" : "Internal error",
    "Not found" : "پیدا نشد",
    "Requested task type does not exist" : "Requested task type does not exist",
    "Necessary language model provider is not available" : "Necessary language model provider is not available",
    "No text to image provider is available" : "نوشتاری برای ارائه‌دهنده تصویر در دسترس نیست",
    "Image not found" : "تصویر یافت نشد",
    "No translation provider available" : "No translation provider available",
    "Could not detect language" : "Could not detect language",
    "Unable to translate" : "Unable to translate",
    "Nextcloud Server" : "کارساز نکست‌کلود",
    "Some of your link shares have been removed" : "برخی از لینک های اشتراک گذاری شده شما حذف شده است",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
    "Learn more ↗" : "بیشتر بدانید ↗",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Repair step:",
    "Repair info:" : "Repair info:",
    "Repair warning:" : "Repair warning:",
    "Repair error:" : "Repair error:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updating database schema" : "به روز رسانی طرح پایگاه داده",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Update app \"%s\" from App Store" : "Update app \"%s\" from App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده %s می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
    "Updated \"%1$s\" to %2$s" : "Updated \"%1$s\" to %2$s",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
    "Already up to date" : "در حال حاضر بروز است",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
    "new" : "جدید",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
    "Update to {version}" : "بروزرسانی به  {version}",
    "An error occurred." : "یک خطا رخ‌داده است.",
    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
    "Continue to {productName}" : "Continue to {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
    "Applications menu" : "منو برنامه‌ها",
    "Apps" : "  برنامه ها",
    "More apps" : "برنامه های بیشتر",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
    "No" : "نه",
    "Yes" : "بله",
    "Failed to add the public link to your Nextcloud" : "خطا در افزودن ادرس عمومی به نکس کلود شما",
    "Create share" : "ساختن اشتراک",
    "Custom date range" : "بازه تاریخی سفارشی",
    "Pick start date" : "انتخاب تاریخ شروع",
    "Pick end date" : "انتخاب تاریخ پایان",
    "Search in date range" : "جستجو در بازه تاریخی",
    "Searching …" : "جستجوکردن …",
    "Start typing to search" : "Start typing to search",
    "Today" : "امروز",
    "Last 7 days" : "۷ روز گذشته",
    "Last 30 days" : "۳۰ روز گذشته",
    "This year" : "امسال",
    "Last year" : "پارسال",
    "Unified search" : "جستجوی یکپارچه",
    "Search apps, files, tags, messages" : "جستجوی برنامه‌ها، پرونده‌ها، برچسب‌ها، پیام‌ها",
    "Places" : "مکان ها",
    "Date" : "تاریخ",
    "Search people" : "جستجوی افراد",
    "People" : "مردم",
    "Results" : "نتایج",
    "Load more results" : "بار کردن نتیحه‌های بیش‌تر",
    "Log in" : "ورود",
    "Logging in …" : "ورود به سیستم ...",
    "Log in to {productName}" : "Log in to {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
    "Account name or email" : "نام کاربری یا آدرس ایمیل",
    "Account name" : "Account name",
    "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "Temporary error" : "خطای موقتی",
    "Please try again." : "لطفا دوباره تلاش کنید.",
    "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Password" : "گذرواژه",
    "Log in with a device" : "Log in with a device",
    "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
    "Your connection is not secure" : "Your connection is not secure",
    "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
    "Browser not supported" : "Browser not supported",
    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Back to login" : "Back to login",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
    "New password" : "گذرواژه جدید",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Resetting password" : "در حال ریست کردن کلمه عبور...",
    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
    "Distraction free note taking app." : "Distraction free note taking app.",
    "Recommended apps" : "Recommended apps",
    "Loading apps …" : "Loading apps …",
    "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
    "App download or installation failed" : "App download or installation failed",
    "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
    "Cannot install this app" : "Cannot install this app",
    "Skip" : "پرش",
    "Installing apps …" : "در حال نصب برنامه",
    "Install recommended apps" : "نصب کاره‌های پیشنهادی",
    "Avatar of {displayName}" : "نمایه {displayName}",
    "Settings menu" : "فهرست تنظیمات",
    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
    "Looking for {term} …" : "به دنبال {term} …",
    "Search contacts" : "Search contacts",
    "Reset search" : "Reset search",
    "Search contacts …" : "جستجو مخاطبین ...",
    "Could not load your contacts" : "Could not load your contacts",
    "No contacts found" : "مخاطبین یافت نشد",
    "Show all contacts" : "نمایش تمام مخاطبین",
    "Install the Contacts app" : "Install the Contacts app",
    "Search" : "جست‌و‌جو",
    "No results for {query}" : "No results for {query}",
    "Press Enter to start searching" : "Press Enter to start searching",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
    "Search for {name} only" : "Search for {name} only",
    "Loading more results …" : "Loading more results …",
    "Forgot password?" : "رمز فراموش شده؟",
    "Back to login form" : "Back to login form",
    "Back" : "بازگشت",
    "Login form is disabled." : "Login form is disabled.",
    "More actions" : "اقدامات بیشتر",
    "Security warning" : "اخطار امنیتی",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Performance warning" : "اخطار کارایی",
    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Database host" : "هاست پایگاه داده",
    "Installing …" : "Installing …",
    "Install" : "نصب",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "{name} version {version} and above" : "{name} version {version} and above",
    "This browser is not supported" : "This browser is not supported",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
    "Continue with this unsupported browser" : "Continue with this unsupported browser",
    "Supported versions" : "Supported versions",
    "Search {types} …" : "Search {types} …",
    "Choose {file}" : "انتخاب {file}",
    "Choose" : "انتخاب کردن",
    "Copy to {target}" : "رونوشت به {target}",
    "Copy" : "کپی",
    "Move to {target}" : "جابجایی به {target}",
    "Move" : "انتقال",
    "OK" : "تایید",
    "read-only" : "فقط-خواندنی",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count}  تضاد در فایل","{count}  تضاد در فایل"],
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "If you select both versions, the copied file will have a number added to its name." : "اگر هر دو نسخه را انتخاب کنید، فایل کپی شده یک شماره به نام آن اضافه خواهد شد.",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Saving …" : "ذخیره کردن …",
    "seconds ago" : "ثانیه‌ها پیش",
    "Connection to server lost" : "اتصال به سرور از دست رفته است",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
    "Add to a project" : "Add to a project",
    "Show details" : "Show details",
    "Hide details" : "مخفی کردن جزئیات",
    "Rename project" : "Rename project",
    "Failed to rename the project" : "Failed to rename the project",
    "Failed to create a project" : "Failed to create a project",
    "Failed to add the item to the project" : "Failed to add the item to the project",
    "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
    "Type to search for existing projects" : "Type to search for existing projects",
    "New in" : "جدید در",
    "View changelog" : "مشاهده تغییرات",
    "No action available" : "هیچ عملی قابل انجام نیست",
    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
    "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
    "Restricted" : "Restricted",
    "Invisible" : "غیر قابل مشاهده",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "Collaborative tags" : "برچسب های همکاری",
    "No tags found" : "هیچ برچسبی یافت نشد",
    "Personal" : "شخصی",
    "Accounts" : "حساب‌ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "Page not found" : "صفحه یافت نشد",
    "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
    "Back to %s" : "Back to %s",
    "Too many requests" : "Too many requests",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "خطا",
    "Internal Server Error" : "خطای داخلی سرور",
    "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
    "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Trace" : "ردیابی",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "Skip to main content" : "Skip to main content",
    "Skip to navigation of app" : "Skip to navigation of app",
    "Go to %s" : "برو به %s",
    "Get your own free account" : "Get your own free account",
    "Connect to your account" : "Connect to your account",
    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
    "Grant access" : " مجوز اعطا دسترسی",
    "Account access" : "دسترسی به حساب",
    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
    "Account connected" : "Account connected",
    "Your client should now be connected!" : "Your client should now be connected!",
    "You can close this window." : "You can close this window.",
    "Previous" : "قبلی",
    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
    "Email address" : "آدرس ایمیل",
    "Password sent!" : "Password sent!",
    "You are not authorized to request a password for this share" : "You are not authorized to request a password for this share",
    "Two-factor authentication" : "Two-factor authentication",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication.",
    "Set up two-factor authentication" : "Set up two-factor authentication",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance.",
    "Use backup code" : "از کد پشتیبان استفاده شود",
    "Cancel login" : "Cancel login",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Enhanced security is enforced for your account. Choose which provider to set up:",
    "Error while validating your second factor" : "Error while validating your second factor",
    "Access through untrusted domain" : "Access through untrusted domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
    "The following apps will be updated:" : "The following apps will be updated:",
    "These incompatible apps will be disabled:" : "این برنامه‌های ناسازگار غیر فعال می‌شوند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "Start update" : "اغاز به روز رسانی",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "نیاز به روز رسانی دارد",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "Maintenance mode" : "Maintenance mode",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
    "Currently open" : "Currently open",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
    "You have not added any info yet" : "You have not added any info yet",
    "{user} has not added any info yet" : "{user} has not added any info yet",
    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
    "Edit Profile" : "ویرایش نمایه",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Profile not found" : "نمایه، یافت نشد",
    "The profile does not exist." : "این نمایه وجود ندارد.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "Show password" : "نمایش گذرواژه",
    "Toggle password visibility" : "Toggle password visibility",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است."
},
"nplurals=2; plural=(n > 1);");
